==> necroplayer_0.2.0.orig.tar.gz: necroplayer-0.2.0.orig/translations/necroplayer_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="11"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <source>Use metadata</source>
        <translation type="obsolete">Использовать метаданные</translation>
    </message>
    <message>
        <source>Use filenames</source>
        <translation type="obsolete">Использовать имена файлов</translation>
    </message>
    <message>
        <source>Update tags when files are added</source>
        <translation type="obsolete">Обновлять теги при добавлении файлов</translation>
    </message>
    <message>
        <source>Update tags when file played</source>
        <translation type="obsolete">Обновлять теги при проигрывании файла</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="19"/>
        <source>Metadata</source>
        <translation>Метаданные</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="21"/>
        <source>Filenames</source>
        <translation>Имена файлов</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="36"/>
        <source>Auto update</source>
        <translation>Обновлять автоматически</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="38"/>
        <source>Update on playing</source>
        <translation>Обновлять при проигрывании</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="47"/>
        <source>Save playlist on quit</source>
        <translation>Сохранять список при выходе</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="60"/>
        <source>Music Directory</source>
        <translation>Директория с музыкой</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="67"/>
        <source>Directory:</source>
        <translation>Директория:</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="75"/>
        <source>Browse</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="82"/>
        <source>Show hidden files</source>
        <translation>Показывать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="97"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>UI</name>
    <message>
        <location filename="../src/UI.cpp" line="48"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="49"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="obsolete">Директория</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="200"/>
        <location filename="../src/UI.cpp" line="208"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>UIControl</name>
    <message>
        <location filename="../src/UIControl.cpp" line="15"/>
        <source>Random</source>
        <translation>Случайно</translation>
    </message>
</context>
<context>
    <name>UIFolder</name>
    <message>
        <location filename="../src/UIFolder.cpp" line="15"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/UIFolder.cpp" line="16"/>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
</context>
<context>
    <name>UIPlaylist</name>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="12"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="15"/>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="18"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
</context>
</TS>

==> necroplayer_0.2.2.orig.tar.gz: necroplayer-0.2.2.orig/translations/necroplayer_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="19"/>
        <location filename="../src/SettingsDialog.cpp" line="47"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <source>Use metadata</source>
        <translation type="obsolete">Использовать метаданные</translation>
    </message>
    <message>
        <source>Use filenames</source>
        <translation type="obsolete">Использовать имена файлов</translation>
    </message>
    <message>
        <source>Update tags when files are added</source>
        <translation type="obsolete">Обновлять теги при добавлении файлов</translation>
    </message>
    <message>
        <source>Update tags when file played</source>
        <translation type="obsolete">Обновлять теги при проигрывании файла</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="27"/>
        <source>Metadata</source>
        <translation>Метаданные</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="29"/>
        <source>Filenames</source>
        <translation>Имена файлов</translation>
    </message>
    <message>
        <source>Auto update</source>
        <translation type="obsolete">Обновлять автоматически</translation>
    </message>
    <message>
        <source>Update on playing</source>
        <translation type="obsolete">Обновлять при проигрывании</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="44"/>
        <source>Retrieve metadata:</source>
        <translation>Извлекать метаданные:</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="49"/>
        <source>Played song</source>
        <translation>Проигрываемое</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="62"/>
        <source>Save playlist on quit</source>
        <translation>Сохранять список при выходе</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="76"/>
        <source>Music Directory</source>
        <translation>Директория с музыкой</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="83"/>
        <source>Directory:</source>
        <translation>Директория:</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="91"/>
        <source>Browse</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="98"/>
        <source>Show hidden files</source>
        <translation>Показывать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="118"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>UI</name>
    <message>
        <location filename="../src/UI.cpp" line="48"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="49"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="obsolete">Директория</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="200"/>
        <location filename="../src/UI.cpp" line="208"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>UIControl</name>
    <message>
        <location filename="../src/UIControl.cpp" line="15"/>
        <source>Random</source>
        <translation>Случайно</translation>
    </message>
</context>
<context>
    <name>UIFolder</name>
    <message>
        <location filename="../src/UIFolder.cpp" line="15"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/UIFolder.cpp" line="16"/>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
</context>
<context>
    <name>UIPlaylist</name>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="12"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="15"/>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="18"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
</context>
</TS>
